@@ -1,7 +1,7 @@
 package App::short;
 
 our $DATE = '2017-01-13'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -119,26 +119,6 @@ sub _validate {
     my $args = shift;
     return [200] if $args->{-validated};
 
-    my $home = _get_my_home_dir() or die "Can't get homedir";
-
-    # replace tilde (~) with home dir
-    for (qw/short_dir long_dir/) {
-        if (defined $args->{$_}) {
-            $args->{$_} =~ s/\A~/$home/;
-        } else {
-            return [400, "Please specify $_"];
-        }
-    }
-
-    # convert to regex
-    if ($args->{long_include}) {
-        for (@{ $args->{long_include} }) {
-            $_ = qr/$_/;
-        }
-    }
-
-    my @caller = caller(1);
-    my $func = $caller[3]; $func =~ s/.+:://;
     if (defined $args->{long}) {
         return [400, "Invalid long name"] if $args->{long} =~ m![/\\]!;
     }
@@ -483,7 +463,7 @@ App::short - Manage short directory symlinks
 
 =head1 VERSION
 
-This document describes version 0.10 of App::short (from Perl distribution App-short), released on 2017-01-13.
+This document describes version 0.11 of App::short (from Perl distribution App-short), released on 2017-01-13.
 
 =head1 SYNOPSIS
 
